@@ -1,9 +1,7 @@
 test_that("search_fullarchive works", {
+  skip_if_offline()
   # Use app with a premium account that matches the env_names
-  if (!"bearer_testing_app" %in% auth_list()) {
-    skip("Requires different authentication")
-  }
-  auth_as("bearer_testing_app")
+  testing_with_authentication("bearer_testing_app")
   expect_snapshot(
     df <- search_fullarchive( q = '#covid place:UK OR place:GB OR place:"United Kindom"',
                               n = 20, env_name = 'fullArchive',
@@ -12,11 +10,9 @@ test_that("search_fullarchive works", {
 })
 
 test_that("search_fullarchive queries bigger than page size work", {
+  skip_if_offline()
   # Use app with a premium account that matches the env_names
-  if (!"bearer_testing_app" %in% auth_list()) {
-    skip("Requires different authentication")
-  }
-  auth_as("bearer_testing_app")
+  testing_with_authentication("bearer_testing_app")
   expect_snapshot(
     df <- search_fullarchive( q = '#covid place:UK OR place:GB OR place:"United Kindom"',
                               n = 20, env_name = 'fullArchive',
@@ -25,11 +21,9 @@ test_that("search_fullarchive queries bigger than page size work", {
 })
 
 test_that("search_fullarchive does not return duplicate tweets", {
+  skip_if_offline()
   # Use app with a premium account that matches the env_names
-  if (!"bearer_testing_app" %in% auth_list()) {
-    skip("Requires different authentication")
-  }
-  auth_as("bearer_testing_app")
+  testing_with_authentication("bearer_testing_app")
   expect_snapshot(
     df <- search_fullarchive(q="#halalan22", n = 450,
                                        env_name = "fullArchive",
